use anyhow::Error;

use super::Repository;
use crate::{database::Queryer, domain::rolle::entity};

impl Repository {
    pub async fn create_rolle<'c, C: Queryer<'c>>(
        &self,
        db: C,
        rolle: &entity::Rolle,
    ) -> Result<entity::Rolle, Error> {
        const QUERY: &str = "insert into rolle (id, created_at, updated_at,
                              name) values ($1, $2, $3, $4) returning *";

        match sqlx::query_as::<_, entity::Rolle>(QUERY)
            .bind(rolle.id)
            .bind(rolle.created_at)
            .bind(rolle.updated_at)
            .bind(&rolle.name)
            .fetch_one(db)
            .await
        {
            Err(err) => {
                tracing::error!("{}", &err);
                Err(err.into())
            }
            Ok(user) => Ok(user),
        }
    }
}
